// 
// 
// 
#include "hpSchedule.h"

void HPScheduleClass::init()
{
}

//Check to see if there is a scheduled start programmed
bool HPScheduleClass::checkScheduleStart() {
	time_t t = now();
	byte dayNow = weekday(t);				//Sun=1, Mon=2, ... Sat=7
	char rtVolts[6];

	bool run = bitRead(runDays, dayNow - 1);
	if (!run) {
		scheduleStartActive = false;
		return false;		//No schedule today
	}

	//A start is scheduled for today, now check if this is the hour/minute
	word current = (hour() * 100) + minute();
	if (((current >= runStart1) && (current <= runStop1) && (runStop1 - runStart1) > 5)||
		((current >= runStart2) && (current <= runStop2) && (runStop2 - runStart2) > 5)||
		((current >= runStart3) && (current <= runStop3) && (runStop3 - runStart3) > 5))
	{
		if ((!scheduleStartActive))
		{
			scheduleStartActive = true;
			DEBUG_PRINTLN("Schedule on");
		}
		return true;
	}
	else
	{
		if (scheduleStartActive)
		{
			scheduleStartActive = false;
			DEBUG_PRINTLN("Schedule off");
		}
	}
	return false;
}

void HPScheduleClass::readSchedule() {
	runDays = eepromUtil.eeprom_read_byte(E_RUNDAYS);
	runStart1 = eepromUtil.eeprom_read_word(E_RUNSTART1);
	runStop1 = eepromUtil.eeprom_read_word(E_RUNSTOP1);
	runStart2 = eepromUtil.eeprom_read_word(E_RUNSTART2);
	runStop2 = eepromUtil.eeprom_read_word(E_RUNSTOP2);
	runStart3 = eepromUtil.eeprom_read_word(E_RUNSTART3);
	runStop3 = eepromUtil.eeprom_read_word(E_RUNSTOP3);

}

String HPScheduleClass::buildSettingsJson() {
	String jsonString;
	char times[6][5];

	// Add values in the object
	const size_t capacity = JSON_OBJECT_SIZE(7) + 120;
	DynamicJsonDocument root(capacity);

	root["runDays"] = runDays;
	snprintf(times[0], sizeof(times[0]), "%04d", runStop1);
	root["runStop1"] = times[0];
	snprintf(times[1], sizeof(times[1]), "%04d", runStart1);
	root["runStart1"] = times[1];
	snprintf(times[2], sizeof(times[2]), "%04d", runStop2);
	root["runStop2"] = times[2];
	snprintf(times[3], sizeof(times[3]), "%04d", runStart2);
	root["runStart2"] = times[3];
	snprintf(times[4], sizeof(times[4]), "%04d", runStop3);
	root["runStop3"] = times[4];
	snprintf(times[5], sizeof(times[5]), "%04d", runStart3);
	root["runStart3"] = times[5];
	serializeJson(root, jsonString);
	return jsonString;
}

void HPScheduleClass::readSettings() {

	runDays = eepromUtil.eeprom_read_byte(E_RUNDAYS);
	runStart1 = eepromUtil.eeprom_read_word(E_RUNSTART1);
	runStop1 = eepromUtil.eeprom_read_word(E_RUNSTOP1);
	runStart2 = eepromUtil.eeprom_read_word(E_RUNSTART2);
	runStop2 = eepromUtil.eeprom_read_word(E_RUNSTOP2);
	runStart3 = eepromUtil.eeprom_read_word(E_RUNSTART3);
	runStop3 = eepromUtil.eeprom_read_word(E_RUNSTOP3);
}

void HPScheduleClass::saveSettings(String json) {

	const size_t capacity = JSON_OBJECT_SIZE(24) + 320;
	DynamicJsonDocument root(capacity);
	deserializeJson(root, json);
	eepromUtil.eeprom_write_byte(E_RUNDAYS, root["runDays"]);
	eepromUtil.eeprom_write_word(E_RUNSTART1, root["runStart1"]);
	eepromUtil.eeprom_write_word(E_RUNSTOP1, root["runStop1"]);
	eepromUtil.eeprom_write_word(E_RUNSTART2, root["runStart2"]);
	eepromUtil.eeprom_write_word(E_RUNSTOP2, root["runStop2"]);
	eepromUtil.eeprom_write_word(E_RUNSTART3, root["runStart3"]);
	eepromUtil.eeprom_write_word(E_RUNSTOP3, root["runStop3"]);
	EEPROM.commit();
	readSettings();
}

HPScheduleClass Schedule;

